EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'SecureResources_CreateOrUpdateSecureResource',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'SecureResource_Id',
    /* Description_Text        */ 'Creates a new secure resource or updates an existing one.'
GO

IF OBJECT_ID('[SecureResources_CreateOrUpdateSecureResource]') IS NOT NULL DROP PROCEDURE [SecureResources_CreateOrUpdateSecureResource]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [SecureResources_CreateOrUpdateSecureResource]
(
	@SecureResource_Name VARCHAR(50),
	@SecureResource_Description NVARCHAR(MAX),
	@Application_Id INT,
    @Configuration_Xml XML,
	@Credential_Name VARCHAR(50),
    @SecureResource_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @SecureResource_Id IS NOT NULL
	BEGIN
		UPDATE [SecureResources]
		   SET [Application_Id] = @Application_Id,
			   [SecureResource_Name] = @SecureResource_Name,
			   [SecureResource_Description] = @SecureResource_Description,
               [Credential_Name] = @Credential_Name,
               [Configuration_Xml] = @Configuration_Xml
         WHERE [SecureResource_Id] = @SecureResource_Id
	END
	ELSE
	BEGIN
		SELECT @SecureResource_Id = [SecureResource_Id]
		  FROM [SecureResources]
		 WHERE [SecureResource_Name] = @SecureResource_Name
		   AND ([Application_Id] = @Application_Id OR ([Application_Id] IS NULL AND @Application_Id IS NULL))

		IF @SecureResource_Id IS NOT NULL
		BEGIN
			UPDATE [SecureResources]
			   SET [Application_Id] = @Application_Id,
				   [SecureResource_Name] = @SecureResource_Name,
				   [SecureResource_Description] = @SecureResource_Description,
			       [Credential_Name] = @Credential_Name,
				   [Configuration_Xml] = @Configuration_Xml
             WHERE [SecureResource_Id] = @SecureResource_Id
		END
		ELSE
		BEGIN
			INSERT INTO [SecureResources] 
			(
				[Application_Id],
	            [SecureResource_Name],
				[SecureResource_Description],
	            [Credential_Name],
	            [Configuration_Xml]
			)
			VALUES
			(
				@Application_Id,
	            @SecureResource_Name,
				@SecureResource_Description,
	            @Credential_Name,
	            @Configuration_Xml
			)

			SET @SecureResource_Id = SCOPE_IDENTITY()
		END
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [SecureResources_CreateOrUpdateSecureResource] TO [BuildMasterUser_Role]
