EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Security_RemovePrivilege',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes a privilege from the system.'
GO

IF OBJECT_ID('[Security_RemovePrivilege]') IS NOT NULL
	DROP PROCEDURE ..[Security_RemovePrivilege]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Security_RemovePrivilege]
(
	@Privilege_Id INT
)
AS
BEGIN
SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DELETE [Privileges]
	 WHERE [Privilege_Id] = @Privilege_Id

	-- Clean up orphaned anonymous roles
	DELETE RT
	  FROM [RoleTasks] RT
	       INNER JOIN [Roles] R
		           ON R.[Role_Id] = RT.[Role_Id]
	 WHERE R.[Role_Name] IS NULL
	   AND RT.[Role_Id] NOT IN (SELECT [Role_Id] FROM [Privileges])

	DELETE R
	  FROM [Roles] R
	 WHERE R.[Role_Name] IS NULL
	   AND R.[Role_Id] NOT IN (SELECT [Role_Id] FROM [Privileges])

	EXEC [Events_RaiseEvent] 'SECDLP', NULL, @Privilege_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Security_RemovePrivilege] TO [BuildMasterUser_Role]
GO
