EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Applications_PurgeApplicationData',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Purges an entire application and all associated data from the system.'
GO

IF OBJECT_ID('[Applications_PurgeApplicationData]') IS NOT NULL DROP PROCEDURE [Applications_PurgeApplicationData]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Applications_PurgeApplicationData]
(
	@Application_Id INT
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Application_Name VARCHAR(50)
	SELECT @Application_Name = [Application_Name]
	  FROM [Applications]
	 WHERE [Application_Id] = @Application_Id

	IF @Application_Name IS NULL
		RAISERROR('Application %i does not exist.', 16, 1, @Application_Id)


	DECLARE @Releases TABLE ([Release_Id] INT PRIMARY KEY NOT NULL)
	INSERT INTO @Releases
	SELECT [Release_Id]
	  FROM [Releases]
	 WHERE [Application_Id] = @Application_Id
	 ORDER BY [Release_Sequence] DESC

	WHILE EXISTS(SELECT * FROM @Releases)
	BEGIN

		DECLARE @Release_Id INT
		SET @Release_Id = (SELECT TOP 1 [Release_Id] FROM @Releases)
		DELETE @Releases WHERE [Release_Id] = @Release_Id

		DECLARE @Release_Number RELEASENUMBER
		SET @Release_Number = (SELECT [Release_Number]
		                         FROM [Releases]
								WHERE [Release_Id] = @Release_Id)

		EXEC [Releases_PurgeReleaseData] @Application_Id, @Release_Number

	END

	DECLARE @Deployables TABLE ([Deployable_Id] INT PRIMARY KEY NOT NULL)
	INSERT INTO @Deployables
	SELECT [Deployable_Id]
	  FROM [Deployables]
	 WHERE [Application_Id] = @Application_Id

	DECLARE @ConfigFiles TABLE ([ConfigurationFile_Id] INT PRIMARY KEY NOT NULL)
	INSERT INTO @ConfigFiles
	SELECT [ConfigurationFile_Id]
	  FROM [ConfigurationFiles]
	 WHERE [Application_Id] = @Application_Id

	DECLARE @DatabaseConnections TABLE ([DatabaseConnection_Id] INT PRIMARY KEY NOT NULL)
	INSERT INTO @DatabaseConnections
	SELECT [DatabaseConnection_Id]
	  FROM [DatabaseConnections]
	 WHERE [Application_Id] = @Application_Id
	 
	-- BEGIN CONFIG FILES --
	DELETE
	  FROM [ConfigurationFileDeployments]
	 WHERE [ConfigurationFile_Id] IN (SELECT [ConfigurationFile_Id] FROM @ConfigFiles)

	DELETE
	  FROM [ConfigurationFileVersions]
	 WHERE [ConfigurationFile_Id] IN (SELECT [ConfigurationFile_Id] FROM @ConfigFiles)

	DELETE
	  FROM [ConfigurationFileInstances]
	 WHERE [ConfigurationFile_Id] IN (SELECT [ConfigurationFile_Id] FROM @ConfigFiles)

	DELETE
	  FROM [ConfigurationFiles]
	 WHERE [ConfigurationFile_Id] IN (SELECT [ConfigurationFile_Id] FROM @ConfigFiles)
    -- END CONFIG FILES --


	-- BEGIN DATABASE CONNECTIONS --
	DELETE
	  FROM [DatabaseChangeScriptExecutions]
	 WHERE [DatabaseConnection_Id] IN (SELECT [DatabaseConnection_Id] FROM @DatabaseConnections)

	DELETE
	  FROM [DatabaseConnections]
	 WHERE [DatabaseConnection_Id] IN (SELECT [DatabaseConnection_Id] FROM @DatabaseConnections)
	-- END DATABASE CONNECTIONS --


	DELETE
	  FROM [EventListenerApplications]
	 WHERE [Application_Id] = @Application_Id

	DELETE
	  FROM [EventOccurenceDetails]
	 WHERE [EventOccurence_Id] IN (SELECT [EventOccurence_Id] FROM [EventOccurences] WHERE [Application_Id] = @Application_Id)

	DELETE
	  FROM [EventOccurences]
	 WHERE [Application_Id] = @Application_Id

	DELETE
	  FROM [Issues]
	 WHERE [Application_Id] = @Application_Id

	DELETE
	  FROM [LogMessages]
	 WHERE [Application_Id] = @Application_Id

	DELETE
	  FROM [Privileges]
	 WHERE [Application_Id] = @Application_Id

	DELETE
	  FROM [RetentionPolicies]
	 WHERE [PurgeIn_Application_Id] = @Application_Id

	DELETE
	  FROM [DeployableDependencies]
	 WHERE [Deployable_Id] IN (SELECT [Deployable_Id] FROM @Deployables)
	    OR [DependsOn_Deployable_Id] IN (SELECT [Deployable_Id] FROM @Deployables)

	DELETE
	  FROM [Deployables]
	 WHERE [Deployable_Id] IN (SELECT [Deployable_Id] FROM @Deployables)

    DELETE
      FROM [DeployablesImported]
     WHERE [Application_Id] = @Application_Id

	DELETE
	  FROM [Applications]
	 WHERE [Application_Id] = @Application_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Applications_PurgeApplicationData] TO [BuildMasterUser_Role]
